database_selection — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# database_selection

class `camelot.view.database_selection.` `ProfileWizard`(profiles, parent=None)

  Wizard for the creation of a new database profile.

  `languages`
  `dialects`

  A list of languages allowed in the profile selection, an empty list will allow all languages

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus